#
# spec file for package kernel-firmware-nvidia-gspx-G06
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gfx_version 550.144.03
%define cuda_version 560.35.03

%global flavor %{?nil}
%if "%{flavor}" == "cuda"
%{bcond_without cuda}
%endif

%define simpletest 0

%define arch x86_64

%if %{undefined _firmwaredir}
%define _firmwaredir /lib/firmware
%endif

Name:           kernel-firmware-nvidia-gspx-G06%{?with_cuda:-cuda}
URL:            https://www.nvidia.com/en-us/drivers/unix/
%if %{with cuda}
Version:        %{cuda_version}
%else
Version:        %{gfx_version}
%endif
Release:        74.1
Summary:        Kernel firmware file for open NVIDIA kernel module driver G06
License:        SUSE-Firmware
Group:          System/Kernel
%if %{without cuda}
Source0:        http://download.nvidia.com/XFree86/Linux-x86_64/%{version}/NVIDIA-Linux-x86_64-%{version}.run
NoSource:       0
%endif
# This is defined at build, not for 'osc service run download_files` or
# factory_auto. This both sources are seen outside of the build but only
# the matching one will be included in the srpm for the respective flavor.
%if %{undefined linux_arch} || %{with cuda}
Source1:        https://developer.download.nvidia.com/compute/cuda/repos/sles15/x86_64/kernel-firmware-nvidia-gspx-G06-%{cuda_version}-0.x86_64.rpm
NoSource:       1
%endif
Source2:        LICENCE.nvidia
Source4:        kernel-firmware-nvidia-gspx-G06-rpmlintrc

# Only required to distinguish between build and factor-auto
BuildRequires:  kernel-macros
BuildRequires:  zstd
%if 0%{simpletest} == 0
Provides:       multiversion(kernel)
%endif
%if %{with cuda}
Provides:       kernel-firmware-nvidia-gspx-G06 = %version
Conflicts:      kernel-firmware-nvidia-gspx-G06
%endif
Obsoletes:      kernel-firmware-nvidia-gsp-G06 = 535.86.05
ExclusiveArch:  x86_64 aarch64
%if 0%{?sle_version} >= 150700
BuildArch:      noarch
%endif

%description
This package contains the versioned kernel firmware file "gsp.bin" for
the OpenSource NVIDIA kernel module driver G06.

%prep
%if %{without cuda}
sh %{_sourcedir}/NVIDIA-Linux-%{arch}-%{version}.run -x
%else
rpm2cpio %{SOURCE1} | cpio -di
%endif
cp %{SOURCE2} .

%build

%install
%if %{without cuda}
mkdir -p %{buildroot}%{_firmwaredir}/nvidia/%{version}
install -m 644 NVIDIA-Linux-%{arch}-%{version}/firmware/{gsp_ga10x.bin,gsp_tu10x.bin} \
  %{buildroot}%{_firmwaredir}/nvidia/%{version}
%if 0%{simpletest} == 1
mkdir -p %{buildroot}/usr/lib/%{name}
install -m 755 ./NVIDIA-Linux-%{arch}-%{version}/nvidia-smi %{buildroot}/usr/lib/%{name}
install -m 755 ./NVIDIA-Linux-%{arch}-%{version}/libnvidia-ml.so.%{version} %{buildroot}/usr/lib/%{name}
ln -snf libnvidia-ml.so.%{version} %{buildroot}/usr/lib/%{name}/libnvidia-ml.so.1
%endif
%else
mkdir -p %{buildroot}%{_firmwaredir}/nvidia/%{version}
install -m 644 ./lib/firmware/nvidia/%{version}/{gsp_ga10x.bin,gsp_tu10x.bin} \
	%{buildroot}%{_firmwaredir}/nvidia/%{version}
%endif

%if 0%{simpletest} == 1
%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%files
%license LICENCE.nvidia
%dir %{_firmwaredir}/nvidia
%dir %{_firmwaredir}/nvidia/%{version}
%{_firmwaredir}/nvidia/%{version}/gsp_ga10x.bin
%{_firmwaredir}/nvidia/%{version}/gsp_tu10x.bin
%if 0%{simpletest} == 1 && %{without cuda}
%dir /usr/lib/%{name}
/usr/lib/%{name}/nvidia-smi
/usr/lib/%{name}/libnvidia-ml.so.%{version}
/usr/lib/%{name}/libnvidia-ml.so.1
%endif

%changelog
* Tue Jan 14 2025 sndirsch@suse.com
- Update 550.144.03 firmware (boo#1235871)
* Sat Jan  4 2025 sndirsch@suse.com
- Update 550.142 firmware (boo#1234675)
* Sat Nov 23 2024 sndirsch@suse.com
- Update 550.135 firmware (boo#1233673)
* Wed Oct 23 2024 sndirsch@suse.com
- For CUDA update version to 560.35.03 (again)
* Wed Oct 23 2024 sndirsch@suse.com
- Update to 550.127.05 (boo#1232057)
* Thu Sep 26 2024 sndirsch@suse.com
- use SUSE-Firmware as License tag in specfile
* Thu Sep 26 2024 sndirsch@suse.com
- switch to official license for NVIDIA firmware files
  - -> https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git/tree/LICENCE.nvidia
* Fri Sep 20 2024 sndirsch@suse.com
- Update to 550.120 (boo#1230779)
* Fri Aug 30 2024 sndirsch@suse.com
- added missing LICENSE file
* Wed Aug 28 2024 sndirsch@suse.com
- reverted CUDA update version to 560.x.y due to changes in CUDA
  repository with CUDA 12.6/560.x.y drivers
* Sun Aug 25 2024 sndirsch@suse.com
- For CUDA update version to 560.35.03
* Mon Aug 12 2024 sndirsch@suse.com
- Update to 550.107.02 (boo#1229716)
* Sat Aug 10 2024 sndirsch@suse.com
- For CUDA update version to 560.28.03
* Fri Jul 12 2024 sndirsch@suse.com
- due to maintenance process we can switch to noarch only for new
  products; so do this only for sle15-sp7 or later
* Thu Jul 11 2024 eich@suse.com
- For CUDA update version to 555.42.6.
- Use firmware for one arch only as firmware doesn't run on
  the CPU and therefore should be arch-independent. This has
  been confirmed by NVIDIA.
  Since the run file attempts to run binaries if these are
  not installed, 'BuildRequire:' zstd.
* Tue Jul  9 2024 sndirsch@suse.com
- Update to 550.100 (boo#1227575)
* Mon Jul  8 2024 eich@suse.com
- Use macro which is set during build but not when running
  `osc service run download_files` to make sure both source versions
  are visible for download. This way, only the correct source
  tarball will be included in the source package of its respective
  flavor but both can be downloaded (updated) simultaniously.
* Fri Jul  5 2024 sndirsch@suse.com
- make buildservice happy; all sources need to be mentioned as such
  in specfile
* Thu Jul  4 2024 sndirsch@suse.com
- Add a second flavor to be used by the kernel module versions
  used by CUDA. The firmware targetting CUDA contains '-cuda' in
  its name to track its versions separately from the graphics
  firmware. (bsc#1227417)
* Tue Jun  4 2024 sndirsch@suse.com
- Security Update 550.90.07
  * addresses boo#1223356 [CVE-2024-0090, CVE-2024-0091, CVE-2024-0092]
* Mon Apr 29 2024 sndirsch@suse.com
- Update to 550.78
  * addresses boo#1223454
* Wed Apr 17 2024 sndirsch@suse.com
- update firmware to version 550.76
  * addresses boo#1222972
* Wed Mar 20 2024 sndirsch@suse.com
- update firmware to version 550.67
* Sat Feb 24 2024 sndirsch@suse.com
- update firmware to version 550.54.14
* Thu Nov 23 2023 sndirsch@suse.com
- update firmware to version 545.29.06
* Mon Nov 13 2023 sndirsch@suse.com
- update firmware to version 545.29.02
* Wed Nov  1 2023 sndirsch@suse.com
- update firmware to version 535.129.03
* Fri Sep 22 2023 sndirsch@suse.com
- update firmware to version 535.113.01
* Mon Aug 28 2023 sndirsch@suse.com
- update firmware to version 535.104.05
* Wed Jul 26 2023 sndirsch@suse.com
- Obsoletes conflicting kernel-firmware-nvidia-gsp-G06 = 535.86.05
  (boo#1212724)
- minor cleanup in specfile
* Wed Jul 26 2023 sndirsch@suse.com
- remove conflicts from previous change again, since this likely
  would break QA test for sle again ...
* Wed Jul 26 2023 sndirsch@suse.com
- added conflicts to kernel-firmware-nvidia-gsp-G06 package
* Tue Jul 25 2023 sndirsch@suse.com
- one-time rename to kernel-firmware-nvidia-gspx-G06 to workaround
  multiversioned package update (boo#1212724)
* Wed Jul 19 2023 sndirsch@suse.com
- update firmware to version 535.86.05
* Thu Jun 15 2023 sndirsch@suse.com
- update firmware to version 535.54.03
  * gsp_ad10x.bin has been renamed to gsp_ga10x.bin
* Wed May 31 2023 sndirsch@suse.com
- make package multiversion capable
  * no longer package libnvidia-ml and nvidia-smi
  * added "Provides: multiversion(kernel)"
* Tue May  9 2023 sndirsch@suse.com
- update firmware to version 525.116.04
* Tue Apr 25 2023 sndirsch@suse.com
- update firmware to version 525.116.03
* Thu Mar 30 2023 sndirsch@suse.com
- update firmware to version 525.105.17
* Wed Feb  8 2023 sndirsch@suse.com
- update firmware to version 525.89.02
* Thu Jan 19 2023 sndirsch@suse.com
- removed old firmware
* Thu Jan 19 2023 sndirsch@suse.com
- update firmware to version 525.85.05
* Thu Jan 19 2023 gmbr3@opensuse.org
- Use _firmwaredir
* Wed Jan 18 2023 jengelh@inai.de
- Remove old specfile constructs
* Wed Jan 18 2023 sndirsch@suse.com
- renamed rpmlintrc to %%{name}-rpmlintrc
* Wed Jan 18 2023 sndirsch@suse.com
- implements jsc#PED-2658
* Mon Jan  9 2023 sndirsch@suse.com
- update firmware to version 525.78.01
* Wed Jan  4 2023 sndirsch@suse.com
- renamed package to kernel-firmware-nvidia-gsp-G06 due to package
  redesign
* Mon Nov 28 2022 sndirsch@suse.com
- update firmware to version 525.60.11
* Fri Nov 11 2022 sndirsch@suse.com
- update firmware to version 525.53
* Tue Oct 18 2022 sndirsch@suse.com
- update firmware to version 515.76
* Wed Aug  3 2022 sndirsch@suse.com
- re-enabled simpletest (nvidia-smi); moved nvidia-smi and
  required libnvidia-ml to /usr/lib/kernel-firmware-nvidia-gsp to
  avoid conflicts with program/lib in nvidia-computeG06; run it with
  LD_LIBRARY_PATH=/usr/lib/kernel-firmware-nvidia-gsp \
    /usr/lib/kernel-firmware-nvidia-gsp/nvidia-smi
* Mon Aug  1 2022 sndirsch@suse.com
- update firmware to version 515.65.01
* Thu Jun 30 2022 sndirsch@suse.com
- update firmware to version 515.57
- no longer enable installation of simpletest (nvidia-smi) in
  order to avoid file conflicts with nvidia-computeG06
* Tue May 31 2022 sndirsch@suse.com
- fixed URL in specfile
* Tue May 31 2022 sndirsch@suse.com
- update firmware to version 515.48.07
* Wed May 25 2022 sndirsch@suse.com
- fixed build on aarch64
* Fri May 20 2022 sndirsch@suse.com
- fixed another warning
- added aarch shell script archive
* Thu May 19 2022 sndirsch@suse.com
- created package
